@@ -51,6 +51,7 @@ my %defaultz =
     # git
 
     git_prefix      => 'perl/',
+    git_repo_file   => 'git-repository.tar',
 );
 
 ########################################################################
@@ -546,7 +547,6 @@ Module::FromPerlVer - install modules compatible with the running perl.
     $madness->$method;
 
 
-
 =head1 DESCRIPTION 
 
 Basic idea: Divide up the source space for a module distro
@@ -557,17 +557,13 @@ distro the module's version compatible with the running
 perl will be selected at install time. No tests in the module
 for $^V are necessary.
 
-=head2 Using the module
-
 Using this module requires two things: The module and a source
 for perl-version-speific files. With "use_dir" the files are
 found in a specific local directory; with "use_git" the are
 found via (guess... if you said "cvs checkout from ./attic"
 you'd be wrong).
 
-=over 4
-
-=item Version Directory
+=head2 Version Directory
 
 The default directory for module versions is "version". This 
 has sub-directories that are parseable as Perl versions:
@@ -578,14 +574,18 @@ has sub-directories that are parseable as Perl versions:
     ./version/v5.24
 
 in each case the basename of the directory is processed by
-version::parse.
+version::parse. The module will find the highest-numified
+version directory that is greater-or-equal to the current
+perl_version (via $^V or set in the module).
 
 The filesystem under each version is whatever dir's and 
 files are suitable for that version of perl. Common 
 examples are README, MANIFEST, Changes, ./lib, ./t,
-./bin.
+./bin. Any files not included in the version directory
+will not be overwritten (e.g., README may be consistent
+for all versions).
 
-=item Version Tag
+=head2 Git and a version tag
 
 With git the current repository is scanned via "git tags"
 with the source prefix. The versions need to look path-ish:
@@ -597,33 +597,88 @@ with the source prefix. The versions need to look path-ish:
 will all do nicely: they have a '/' with a "basename" of
 a parsable perly version.
 
-=item Git in the MANIFEST
+The trick is getting a working .git into the module
+distribution. As always, there is more than one way.
 
-The git checkout requires a working git repository to work
-in. This means that your tarball must be a working clone of
-the repository. That in turn menas that the MANIFEST include
-everything required to copy a working repository.
+The check for using git starts with locating an existing
+./.git directory, checking the tarball parameter, then
+using a URL. During development in a working git repository
+there is no need for the tarball since ./.git will exist;
+after that if the tarball parameter is provided it must
+exist or the extractor will die at runtime unable to find
+it; after that if the git_url is provided then an attempt
+will be made to clone the repository and extract its .git
+directory for the checkout.
 
-Basically:
+Providing either the tarball or URL arguments without a
+.git directory and existing tarball/working service will
+result in the death of your install.
+
+=over 4
+
+=item Git extract via tarball
+
+Probably the simplest fix is to tarball your .git directory
+and add the tarball to your manifest:
+
+    $ find .git | sort -d | cpio -ov -Htar > local_repo.tar;
+
+add "local_repo.tar" to your MANIFEST and then 
+
+    use Module::FromPerlVer
+    qw
+    (
+        use_git     1
+        git_tarball local_repo.tar
+    );
+
+call the tarball whatever you like (there is no default for
+it, yet).
+
+At that point the git extractor will extract the tarball,
+check for a ./.git directory, croak if there isn't one, 
+and check out the tags.
+
+=item Git clone via URL
+
+This is still in-work, there are enough issues to cloning a 
+URL for general consumption (e.g., without a network) that it
+may take a while to make this work reliably.
+
+    use Module::FromPerlVer
+    qw
+    (
+        use_git     1
+        git_url     https://foo.bar.com/whatever.git
+    );
+
+will do a "git clone", look for the ./whatever directory
+(i.e., sans ".git"), and go from there.
+
+Please relize that using this approach leaves anyone without
+a network connection unable to install the module.
+
+=item Bundling a ./.git directory
+
+This is the easiest to work with if you are developing the 
+module in a git repository. The git version extractor will
+find a ./.git directory when it starts up and keep going.
+
+Catch here is that if you don't make the tarball or use a
+URL, the module's distro will require the contents
+of ./.git in the MANIFEST. This is quite doable via 
 
     find .git -type >> MANIFEST;
 
-will do the trick. You might not want to copy all of your
-hook files, etc, in which case feel free to copy whatever
-minimal repository you wish.
+but can lead to a rather large-ish manifest.
 
-Aside:
+Feel free to filter out any hook files, etc, that are
+not related to your version tags. The only necessity 
+is a working "git tag --list" and "git checkout $tag".
 
-    The alternative is that noone can install the module without a 
-    working network connection (not simply test it, the repository 
-    must be accessible for "perl Makefile.PL" to extract the 
-    appropriate version tag).
+=back
 
-Anyone with a strong opinion one way or the other should 
-feel free t contact me about this.
-
-
-=item Basic Use
+=head2 Options
 
 Using the module in setup code (e.g., Makefile.PL):
 
@@ -641,6 +696,8 @@ Versions derived from "use" will be less than equal to that
 version, versions derived from "no" will be less than or 
 equal to the version minus 0.000001.
 
+=over 4
+
 =item Supplying the Perl Version
 
 It may be useful in testing to choose a specific subdirectory
@@ -655,8 +712,6 @@ version string being parsed.
 In order of priority the Perl version used to select the 
 module's compatible directory are:
 
-=over 4
-
 =item $ENV{ PERL_VERSION }
 
 Any true value of  will be used. If this is supplied with
@@ -725,13 +780,13 @@ below) but will not execute get_files().
 
 =back
 
-=back
-
 =head2 Use Messages
 
 The module supplies most of the information necessary to 
 debug environment and configuration issues when import()
-is called:
+is called.
+
+For example, using a version directory gives:
 
     # Def: default_use = 'dir'
     # Def: version_dir = 'version'
@@ -748,18 +803,22 @@ is called:
     # Install cleanup.
     # Get files with: 'Dir'
 
+The leading '#' are included to avoid causing trouble with 
+modules that depend on TAP.
 
 =over 4
 
 =item Configuration
 
+Prefixes are 'Def', 'Env', 'Arg' which show where the values came 
+from.
+
+For exmaple, these are default values:
+
     # Def: default_use = 'dir'
     # Def: version_dir = 'version'
     # Def: git_prefix = 'perl/'
 
-There are three variants: 'Def', 'Env', 'Arg' which 
-show where the values came from. 
-
 =item Handler
 
 This shows which of use_* or the default_use was
@@ -775,7 +834,7 @@ basic information about the values selected from
 the arguments, perl version, and workspace.
 
 See "Utility Subs" (below) for more information on
-what these mean.
+their use.
 
 =back
 
@@ -792,10 +851,10 @@ re-set the values determined at import time.
 None of them are exported, they can be called usig either 
 package or object notation:
 
-    Module::FromPerlVer::get_files;   # package::subname
+    Module::FromPerlVer::get_files; # package::subname
 
-    Module::FromPerlVer->cleanup;           # class->method
-    $module_name->cleanup;
+    Module::FromPerlVer->cleanup;   # class->method
+    $madness->cleanup;              # useful for testing.
 
 None of them exist until import() is called: requiring 
 Module::FromPerlVer will not install any of them.
@@ -821,21 +880,21 @@ paths with the identical effect:
 Returns the parsed, numified Perl version value (see 
 version module).
 
-=item version_source()
+=item version_prefix()
 
-Returns the source of the version directory
-(e.g., dir "version" or tag "perl/").
+Returns the version dir's relative path or git tag
+prefix (e.g., "version", "perl/").
 
 =item version_source()
 
 The subdir or tag from which the files are sourced. This will 
-be a relative path from $FindBin::Bin, including the 
-version directory:
+be a relative path from $FindBin::Bin or a full git tag:
 
     ./version/5.006001
     ./version/v5.24.2
 
     perl/v5.24
+    perl/5.8.8
     perl5.005_003
 
 =item source_files()
@@ -897,6 +956,12 @@ wherever you work -- with the tags behind.
 
 =over 4
 
+=item Module::FromPerlVer::{Git,Dir}
+
+These do the low-level work of dealing with directories or 
+Git repositories. POD in them descibes the progress messages,
+error, and exceptions.
+
 =item version
 
 This does the parsing of version numbers from code and 
